@@ -10,6 +10,8 @@ from .hlt_doctor_visit_table import HltDoctorVisitTable
 from .hlt_lpu_doctor import HltLpuDoctor
 from .hlt_med_record import HltMedRecord
 from .hlt_mkab import HltMkab, Gender
+from .hlt_mkb_tap import HltMkbTap
+from .oms_kl_diagnos_type import OmsKlDiagnosType
 from .hlt_polis_mkab import HltPolisMkab
 from .hlt_reason_care import HltReasonCare
 from .hlt_representative_mkab import HltRepresentativeMkab
